# Conduct validation of parameter estimation
library(abc)
n.pod <- 1000 # number of pseudo observed data set

prior <- read.table(file = "../prior.txt", header = TRUE)
ss <- read.table(file = "../sumstat.txt", header = TRUE)

n.param <- ncol(prior)
use.ss <- names(ss)
ss <- ss[, use.ss]

## Range of priors
bounds <- matrix(c(1, 10000, # NCUR
                   1, 10000, # NANC
                   -0.01, 0, # GRATE
                   1, 10000, # TDIV1
                   1, 10000, # TDIV2
                   0.1, 20, # NM
                   0.5, 2, # MUT_SHAPE
                   0, 0.8), # P_MEAN
                 nrow = n.param, ncol = 2, byrow = TRUE)

out <- matrix(NA,nrow = n.pod, ncol = n.param)
out <- as.data.frame(out)
names(out) <- names(prior)

## Calculate posterior quantile with pod
for(i in 1:n.pod) {
    ## abc with pod
    x <- sample(1:nrow(prior), size = 1)
    pod <- ss[x, ] # pseudo observed data
    param.temp <- prior[x, ] # parameters that generated pod
    res <- abc(target = pod,
               param = prior[-x, ], # remove x
               sumstat = ss[-x, ], # remove x
               tol = 0.0005,
               method = "neuralnet", numnet = 20,
               transf = "logit", logit.bounds = bounds)
    posterior <- as.data.frame(res$adj.values)

    ## Calculate posterior quantile
    for(j in 1:n.param) {
        fn <- ecdf(posterior[, j])
        out[i, j] <- fn(param.temp[j])
    }
    print(paste(i, "/", n.pod, "calculations have finished."))
}

write.table(round(out, 3), file = "posterior_quantile.txt",
            quote = FALSE, row.names = FALSE, sep = "\t")


