# Make figs of posterior quantile
# 180421 Adjust figure size
library(ggplot2)
library(reshape)

#d <- read.table("posterior_quantile_5000.txt", header = TRUE)
d <- read.table("posterior_quantile.txt", header = TRUE)

d[d == 0] <- 0.001 # adjust boundary values
d[d == 1] <- 0.999

gd <- melt(d)
names(gd) <- c("Parameter", "Value")
use.parameter <- unique(gd$Parameter)
n.param <- length(use.parameter)

## Calc P-value when an uniform dist was assumed
gd.p <- data.frame(Parameter = use.parameter,
                   Value = NA)
options(warn = -1) # Turn off warinings when ks.test
for(i in 1:n.param) {
    temp <- ks.test(d[, use.parameter[i]], "punif", 0, 1)
    gd.p$Value[i] <- temp$p.value
}
options(warn = 0) # Turn on warnings
gd.p$Value <- round(p.adjust(gd.p$Value, "bonferroni"), 3)
gd.p$Text <- "n.s."
for(i in 1:n.param) {
    if(gd.p$Value[i] > 0.001 & gd.p$Value[i] < 0.05) {
        gd.p$Text[i] <- paste("P = ", gd.p$Value[i], sep = "")
    }
    if(gd.p$Value[i] < 0.001) {
        gd.p$Text[i] <- "P < 0.001"
    }
}

## Make uniform dist data
uniform.dist <- nrow(d)/10 # number of counts when it distributes uniform
gd.hline <- data.frame(Parameter = use.parameter,
                       Value = rep(uniform.dist, rep = n.param))

## Set labels for facet
levels(gd$Parameter)[levels(gd$Parameter) == "NCUR"] <- "italic(N)[CUR]"
levels(gd$Parameter)[levels(gd$Parameter) == "NANC"] <- "italic(N)[ANC]"
levels(gd$Parameter)[levels(gd$Parameter) == "GRATE"] <- "italic(G)"
levels(gd$Parameter)[levels(gd$Parameter) == "TDIV1"] <- "italic(T)[1]"
levels(gd$Parameter)[levels(gd$Parameter) == "TDIV2"] <- "italic(T)[2]"
levels(gd$Parameter)[levels(gd$Parameter) == "NM"] <- "italic(Nm)"
levels(gd$Parameter)[levels(gd$Parameter) == "MUT_SHAPE"] <- "italic(shape)"
levels(gd$Parameter)[levels(gd$Parameter) == "P_MEAN"] <- "mean~~italic(P)[GSM]"

levels(gd.p$Parameter)[levels(gd.p$Parameter) == "NCUR"] <- "italic(N)[CUR]"
levels(gd.p$Parameter)[levels(gd.p$Parameter) == "NANC"] <- "italic(N)[ANC]"
levels(gd.p$Parameter)[levels(gd.p$Parameter) == "GRATE"] <- "italic(G)"
levels(gd.p$Parameter)[levels(gd.p$Parameter) == "TDIV1"] <- "italic(T)[1]"
levels(gd.p$Parameter)[levels(gd.p$Parameter) == "TDIV2"] <- "italic(T)[2]"
levels(gd.p$Parameter)[levels(gd.p$Parameter) == "NM"] <- "italic(Nm)"
levels(gd.p$Parameter)[levels(gd.p$Parameter) == "MUT_SHAPE"] <- "italic(shape)"
levels(gd.p$Parameter)[levels(gd.p$Parameter) == "P_MEAN"] <- "mean~~italic(P)[GSM]"

levels(gd.hline$Parameter)[levels(gd.hline$Parameter) == "NCUR"] <- "italic(N)[CUR]"
levels(gd.hline$Parameter)[levels(gd.hline$Parameter) == "NANC"] <- "italic(N)[ANC]"
levels(gd.hline$Parameter)[levels(gd.hline$Parameter) == "GRATE"] <- "italic(G)"
levels(gd.hline$Parameter)[levels(gd.hline$Parameter) == "TDIV1"] <- "italic(T)[1]"
levels(gd.hline$Parameter)[levels(gd.hline$Parameter) == "TDIV2"] <- "italic(T)[2]"
levels(gd.hline$Parameter)[levels(gd.hline$Parameter) == "NM"] <- "italic(Nm)"
levels(gd.hline$Parameter)[levels(gd.hline$Parameter) == "MUT_SHAPE"] <- "italic(shape)"
levels(gd.hline$Parameter)[levels(gd.hline$Parameter) == "P_MEAN"] <- "mean~~italic(P)[GSM]"



## Make ggplot
g <- ggplot(data = gd, aes(x = Value)) +
    geom_histogram(binwidth = 0.1, fill = "grey60", boundary = 0) +
    labs(x = "Parameter", y = "Count") +
    facet_wrap(~ Parameter, ncol = 4, labeller = label_parsed) +
    theme_bw()

g <- g + # Add uniform dist
    geom_hline(data = gd.hline, aes(yintercept = Value), linetype = "dashed")

g <- g + # Add p-values
    geom_text(data = gd.p, aes(x = 0.5, y = uniform.dist/5, label = Text))

## Output
pdf(file = "posterior_quantile180421.pdf", width = 10, height = 4.5)
print(g)
dev.off()

