# Make data for posterior prediction
library(abc)

n.locus <- 27
n.pred.sim <- 1000

load(file = "posterior.RData")
posterior <- as.data.frame(res$adj.values)

# 1) Structural parameters
# Units of effective population sizes are number of diploid individuals
NCUR <- posterior$NCUR
NANC <- posterior$NANC

# Growth rate
GRATE <- posterior$GRATE

# Unit of time is number of generations
TDIV1 <- posterior$TDIV1
TDIV2 <- posterior$TDIV2

# Migrations are set to Nm (number of migrants per generation)
NM <- posterior$NM

# 2) Mutation parameters
MUT_SHAPE <- posterior$MUT_SHAPE
P_MEAN <- posterior$P_MEAN

## Convert priors into forms that were handed to fsc2 with -f option
NCUR_HAP <- 2*NCUR
NT1 <- NCUR*exp(GRATE*TDIV1) # Ne at TDIV1
RSIZE <- NANC/NT1

# NM are converted into migration rate (m)
MIG <- NM/NCUR
MIG[MIG > 1] <- 0.999 # 0 < MIG < 1

# Adjust mus in each locus (Excoffier et al. 2005)
MUT_MEAN <- 0.0005 # Mean mu was fixed
shape <- MUT_SHAPE
rate <- shape/MUT_MEAN

# Adjust Ps in each locus
a <- 0.5+199*P_MEAN
b <- a*(1-P_MEAN)/P_MEAN

for(i in 1:n.locus) {
    if(nchar(i) == 1) {
        assign(paste("P", "0", i, sep = ""), rbeta(nrow(posterior), a, b))
        assign(paste("MUT", "0", i, sep = ""),
               rgamma(nrow(posterior), shape, rate))
    }
    if(nchar(i) == 2) {
        assign(paste("P", i, sep = ""), rbeta(nrow(posterior), a, b))
        assign(paste("MUT", i, sep = ""),
               rgamma(nrow(posterior), shape, rate))
    }
}
out <- data.frame(NCUR_HAP, RSIZE, GRATE,
                  TDIV1, TDIV2,
                  MIG,
                  MUT01, MUT02, MUT03, MUT04, MUT05, MUT06, MUT07, MUT08,
                  MUT09, MUT10, MUT11, MUT12, MUT13, MUT14, MUT15, MUT16,
                  MUT17, MUT18, MUT19, MUT20, MUT21, MUT22, MUT23, MUT24,
                  MUT25, MUT26, MUT27,
                  P01, P02, P03, P04, P05, P06, P07, P08, P09, P10,
                  P11, P12, P13, P14, P15, P16, P17, P18, P19, P20,
                  P21, P22, P23, P24, P25, P26, P27)

## Remove irregular values (i.e. TDIV1 > TDIV2)
use.data <- (1:nrow(out))[out$TDIV1 < out$TDIV2]
use.data <- sample(use.data, n.pred.sim, rep = TRUE)
out <- out[use.data, ]

## make directory and 
system("mkdir -p posterior_pred")
write.table(out, file = "./posterior_pred/posterior.txt",
            row.names = FALSE, quote = FALSE)

