# Run Model3C (admixture 2 with expansion)

n.total.sim <- 1*10^4 # number of total sims (> 10^2)
n.sim.per.batch <- 100 # number of sim per 1 batch
n.batch <- n.total.sim/n.sim.per.batch # number of batch
n.locus <- 27 # number of loci
outfile <- "sumstat.txt"

fsc <- "/Users/ichiro/works/programs/fsc_mac64/fsc25221" # path for fsc2
tpl <- "model3C.tpl" # path for tpl file
arlsumstat <- "/Users/ichiro/works/programs/arlsumstat_macosx/arlsumstatmac_64bit" # path for arlsumstat
arl_run <- "../observed/arl_run.ars" # path for arl_run.ars
ssdefs <- "../observed/ssdefs.txt" # path for ssdefs.txt

## collect files needed
system(paste("cp", arl_run, "."))
system(paste("cp", ssdefs, "."))

## Make priors (5 digits enough for LOG scale)
# 1) Structural parameters
# Units of effective population sizes are number of diploid individuals
NCUR <- as.integer(runif(n.total.sim, 1, 10000))
NANC <- as.integer(runif(n.total.sim, 1, 10000))

# Growth rate
GRATE <- round(runif(n.total.sim, -0.01, 0), 6)

# PROP21 of Pop2 join into Pop1 and remaining Pop2 join into Pop3
# i.e. PROP21 is an admixture rate
PROP21 <- round(runif(n.total.sim, 0, 1), 3)

# PROP41 of Pop4 join into Pop1 and remaining Pop4 join into Pop3
# i.e. PROP41 is an admixture rate
PROP41 <- round(runif(n.total.sim, 0, 1), 3)

# Unit of time is number of generations
TDIV1 <- temp1 <- as.integer(runif(n.total.sim, 1, 10000))
TDIV2 <- temp2 <- as.integer(runif(n.total.sim, 1, 10000))

# Sort TDIV1<TDIV2
TDIV1[temp1 > temp2] <- temp2[temp1 > temp2]
TDIV2[temp1 > temp2] <- temp1[temp1 > temp2]
rm(temp1, temp2) # Remove temporal files

# 2) Mutation parameters
MUT_SHAPE <- round(runif(n.total.sim, 0.5, 2), 3) # Gamma dist. for variance in mutation rates among loci

P_MEAN <- round(runif(n.total.sim, 0, 0.8), 3) # Mean P for GSM

# Output priors for rater analysis
prior.out <- data.frame(NCUR, NANC, GRATE,
                        PROP21, PROP41,
                        TDIV1, TDIV2,
                        MUT_SHAPE, P_MEAN)
write.table(prior.out, "prior.txt", quote = FALSE, sep = " ", row.names = FALSE)
rm(prior.out)

## Convert priors into forms that were handed to fsc2 with -f option
NCUR_HAP <- 2*NCUR
NT1 <- NCUR*exp(GRATE*TDIV1) # Ne at TDIV1
RSIZE <- NANC/NT1

# Adjust mus in each locus (Excoffier et al. 2005)
MUT_MEAN <- 0.0005 # Mean mu was fixed
shape <- MUT_SHAPE
rate <- shape/MUT_MEAN

# Adjust Ps in each locus
a <- 0.5+199*P_MEAN
b <- a*(1-P_MEAN)/P_MEAN

for(i in 1:n.locus) {
    if(nchar(i) == 1) {
        assign(paste("P", "0", i, sep = ""), rbeta(n.total.sim, a, b))
        assign(paste("MUT", "0", i, sep = ""),
               rgamma(n.total.sim, shape, rate))
    }
    if(nchar(i) == 2) {
        assign(paste("P", i, sep = ""), rbeta(n.total.sim, a, b))
        assign(paste("MUT", i, sep = ""),
               rgamma(n.total.sim, shape, rate))
    }
}
prior <- data.frame(NCUR_HAP, RSIZE, GRATE,
                    PROP21, PROP41,
                    TDIV1, TDIV2,
                    MUT01, MUT02, MUT03, MUT04, MUT05, MUT06, MUT07, MUT08,
                    MUT09, MUT10, MUT11, MUT12, MUT13, MUT14, MUT15, MUT16,
                    MUT17, MUT18, MUT19, MUT20, MUT21, MUT22, MUT23, MUT24,
                    MUT25, MUT26, MUT27,
                    P01, P02, P03, P04, P05, P06, P07, P08, P09, P10,
                    P11, P12, P13, P14, P15, P16, P17, P18, P19, P20,
                    P21, P22, P23, P24, P25, P26, P27)

## Simulate only 1 time for making header of the outfile
sim.dir <- unlist(strsplit(tpl, ".tpl"))
arp.file <- paste("./", sim.dir, "/", sim.dir, "_1_1.arp", sep = "")

write.table(prior[1, ], "temp_prior.txt",
            quote = FALSE, sep = " ", row.names = FALSE)
system(paste(fsc, "-t", tpl, "-n 1 -f", "temp_prior.txt", "-g"))
system(paste(arlsumstat, arp.file, outfile, 0, 2))

## Run sumulation for each batch
# Make arpfile name list
arp.file <- paste("./", sim.dir, "/", sim.dir, "_",
                  1:n.sim.per.batch, "_1.arp", sep = "")

for(i in 1:n.batch) {
    data.location <- ((i-1)*n.sim.per.batch+1):(i*n.sim.per.batch) # get location of data in ith batcn
    write.table(prior[data.location, ], "temp_prior.txt",
                quote = FALSE, sep = " ", row.names = FALSE)
    system(paste(fsc, "-t", tpl, "-n 1 -f", "temp_prior.txt", "-g"))
    for(j in 1:n.sim.per.batch) {
        system(paste(arlsumstat, arp.file[j], outfile, 1, 0))
    }
}

## Cleaning
system(paste("rm -rf", sim.dir))
system("rm temp_prior.txt")
system("rm *seed.txt")
system("rm arl_run.ars")
system("rm ssdefs.txt")

system("rm -f arl_pro.txt")
print("Simultions have been completed!")
