# Model comparison using abcrf
# Compare 4 models
# All models consider population expansion
# All models except for admixture consider migration
# model2C (2 refusia)            -> model1
# model4C (3 refugia)            -> model2
# model1E (insect)               -> model3
# model3C (admixture, TESS, K=2) -> model4

require(abcrf)
n.use.sim <- 1*10^4
n.tree <- 10^3

## summary statistics of observed data
ss.data <- read.table(file = "/Users/ichiro/works/works14/aoki/abc_fsc2/observed/observed_castanopsis4pop100ind.txt", header = TRUE)

## summary statistics of simulated data
ss.model2C <- read.table(file = "/Users/ichiro/works/works14/aoki/abc_fsc2/model2C/sumstat.txt", header = TRUE)

ss.model4C <- read.table(file = "/Users/ichiro/works/works14/aoki/abc_fsc2/model4C/sumstat.txt", header = TRUE)

ss.model1E <- read.table(file = "/Users/ichiro/works/works14/aoki/abc_fsc2/model1E/sumstat.txt", header = TRUE)

ss.model3C <- read.table(file = "/Users/ichiro/works/works14/aoki/abc_fsc2/model3C/sumstat.txt", header = TRUE)

## preparing input data
ss.model2Cex <- ss.model2C[1:n.use.sim, ] # extracted data
ss.model4Cex <- ss.model4C[1:n.use.sim, ]
ss.model1Eex <- ss.model1E[1:n.use.sim, ]
ss.model3Cex <- ss.model3C[1:n.use.sim, ]

modindex <- factor(rep(1:4, each = n.use.sim))
sumsta <- rbind(ss.model2Cex, # 2 refugia
                ss.model4Cex, # 3 refugia
                ss.model1Eex, # insect
                ss.model3Cex) # admixture, TESS, K=2

data.rf <- data.frame(modindex, sumsta)

## abcrf
model.rf <- abcrf(modindex ~ ., data = data.rf, lda = TRUE,
                  ntree = n.tree, paral = TRUE)
print(model.rf)
out.rf <- predict(model.rf, obs = ss.data, training = data.rf,
                  ntree = n.tree, paral = TRUE)
print(out.rf)

## model check
if(0) {
    ## Check the locations of observed and simulated data
    plot(model.rf, obs = ss.data, training = data.rf)
    ## Confirm number of trees
    err.abcrf(model.rf, training = data.rf, paral = TRUE)
}

#Out-of-bag prior error rate: 11.5525%
#
#Confusion matrix:
#     1    2    3    4 class.error
#1 8974  726  155  145      0.1026
#2  692 7624 1621   63      0.2376
#3  154  929 8877   40      0.1123
#4   49   41    6 9904      0.0096
#  selected model votes model1 votes model2 votes model3 votes model4 post.proba
#1              1        0.634        0.212        0.152        0.002  0.9062167



