# Summarize posterior of model2C
library(abc)
library(coda)

## Function for calculation of mode and HPD
calc.mode.hpd <- function(x, pow10 = FALSE) {
    temp <- density(x)
    m <- temp$x[temp$y == max(temp$y)]
    phd <- HPDinterval(as.mcmc(x))
    if(pow10) {
        return(10^c(m, phd))
    }
    else {
        return(c(m, phd))
    }
}

## Make container
parameter <- c("NCUR", "NANC", "GRATE", "TDIV1", "TDIV2",
               "NM", "MUT_SHAPE", "P_MEAN")
n.parameter <- length(parameter)
out <- data.frame(Parameter = parameter,
                  Mode = rep(NA, n.parameter),
                  Lower = rep(NA, n.parameter),
                  Upper = rep(NA, n.parameter))

## Load data and put calculated value into container
load("/Users/ichiro/works/works14/aoki/abc_fsc2/model2C/param_est/posterior.RData")
posterior <- as.data.frame(res$adj.values)
for(i in 1:n.parameter) {
    param.name <- names(posterior)[i]
    x <- posterior[, param.name]
    LOG10 <- length(grep("LOG10_", param.name)) == 1 # T or F for LOG10
        if(LOG10) { # Remove LOG10_ from parameter name, which was scaled in LOG10
            param.name <- unlist(strsplit(param.name, "LOG10_"))[2]
        }
        out[out$Parameter == param.name, c("Mode", "Lower", "Upper")] <-
            calc.mode.hpd(x, pow10 = LOG10)    
}

## Output
system("mkdir -p ./output")
write.table(out, file = "./output/posterior_summary_model2C.csv", quote = FALSE,
            row.names = FALSE, sep = ",")


## Calculate mode and HPD of Ne at TDIV1
NT1 <- posterior$NCUR*exp(posterior$GRATE*posterior$TDIV1)
summary.NT1 <- calc.mode.hpd(NT1)
#[1] 1.467887e+03 9.889091e-02 3.227529e+03
#plot(density(NT1)) # Denisty plot showed single clear peak.


